<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Mark-As-Junk plugin        |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+

 For translation see https://www.transifex.com/projects/p/roundcube-webmail/resource/plugin-markasjunk/
*/

$labels['buttonjunk'] = 'Ky mesazh është hedhurinë';
$labels['asjunk'] = 'Si hedhurinë';
$labels['markasjunk'] = 'Vëri shenjë si hedhurinë';
$labels['buttonnotjunk'] = 'Ky mesazh s’është hedhurinë';
$labels['asnotjunk'] = 'Si jo hedhurinë';
$labels['markasnotjunk'] = 'Vëri shenjë si jo hedhurinë';
$labels['notjunk'] = 'Jo hedhurinë';
$messages['reportedasjunk'] = 'U raportua me sukses si hedhurinë';
$messages['reportedasnotjunk'] = 'U raportua me sukses si jo hedhurinë';
